// ***************************************************************
//  main   version:  1.0     date: 10/10/2007
//  -------------------------------------------------------------
//  Dijkstra_adjacency-matrix representation
//  -------------------------------------------------------------
//  Copyright FrozenFire(C) 2007 - All Rights Reserved
// ***************************************************************
//     ,     
//      ,  0 - , 1 - , 
//       (0,0)  (x, y),  x  y -  
// ***************************************************************
#include <algorithm>
#include <iostream>
#include <fstream>
#include <vector>
#include <windows.h>
using namespace std;

struct SData {
	WPARAM data;
	int _path;// 
	int _prev;// 
	SData( WPARAM _data ) {
		data = _data;
		//     
		_path = INT_MAX;
		_prev = -1;
	}
};

struct SGraph{
	vector< SData > vertex;
	int ** matrix;

	void CreateGraph() {
		matrix = new int* [vertex.size()];
		for( int i = 0; i < (int)vertex.size(); ++i ) {
			matrix[i] = new int[vertex.size()];
			for( int j = 0; j < (int)vertex.size(); ++j ) {
				matrix[i][j] = INT_MAX;//   
			}
		}
	}
	void DeleteGraph() {
		for( int i = 0; i < (int)vertex.size(); ++i ) {
			delete[] matrix[i];
		}
		delete[] matrix;
		vertex.clear();
	}
	int GetNumVertex( WPARAM dateV ) {
		for( int i = 0; i < (int)vertex.size(); ++i ) {
			if( vertex[i].data == dateV ) {
				return i;
			}
		}
		throw 0;
	}
	void SetEdge( WPARAM dateV1, WPARAM dateV2, int dataE1, int dataE2 = 0, bool revers = false ) {
		int from = GetNumVertex( dateV1 );
		int to = GetNumVertex( dateV2 );
		matrix[from][to] = dataE1;
		if( revers ) {
			matrix[to][from] = dataE2;
		}
	}
	void Dijkstra( WPARAM dateV1, WPARAM dateV2, vector< WPARAM > & path ) {
		int from = GetNumVertex( dateV1 );
		int to = GetNumVertex( dateV2 );
		vector< int > tempVertex;// 
		for( int i = 0; i < (int)vertex.size(); ++i ) {
			tempVertex.push_back( i );
		}
		//  
		vertex[from]._path = 0;
		while( tempVertex.size() ) {
			int minVertex = ExtractMinVertex( tempVertex );
			//  
			for( int i = 0; i < vertex.size(); ++i ) {
				Relax( minVertex, i );
			}
		}
		//  
		while( to != -1 ) {
			path.push_back( vertex[to].data );
			to = vertex[to]._prev;
		}
		reverse( path.begin(), path.end() );
	}
	int ExtractMinVertex( vector< int > & tempVertex ) {
		//      
		//     
		int minimum = INT_MAX;
		int numMuninunVetex = -1;
		int numVector = -1;
		for( int i = 0; i < tempVertex.size(); ++i ) {
			if( vertex[tempVertex[i]]._path < minimum ) {
				minimum = vertex[tempVertex[i]]._path;
				numMuninunVetex = tempVertex[i];
				numVector = i;
			}
		}
		if( numVector == -1 ) {
			throw 0;
		}
		tempVertex.erase( tempVertex.begin() + numVector );
		return numMuninunVetex;
	}
	void Relax( int numVertexFrom, int numVertexTo ) {
		if( matrix[numVertexFrom][numVertexTo] != INT_MAX ) {
			if( vertex[numVertexTo]._path > vertex[numVertexFrom]._path + matrix[numVertexFrom][numVertexTo] ) {
				vertex[numVertexTo]._path = vertex[numVertexFrom]._path + matrix[numVertexFrom][numVertexTo];
				vertex[numVertexTo]._prev = numVertexFrom;
			}
		}
	}
};
void init( int ** matrix, int x, int y, SGraph & g ) {
	//   ,  1   
	for( int j = 0; j < y; ++j ) {
		for( int i = 0; i < x; ++i ) {
			if( matrix[i][j] == 0 ) {
				if( i-1 >= 0 && j-1 >= 0 ) if( matrix[i-1][j-1] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i-1, j-1 ), 1 );
				}
				if( j-1 >= 0 ) if( matrix[i][j-1] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i, j-1 ), 1 );
				}
				if( i+1 < x && j-1 >= 0 ) if( matrix[i+1][j-1] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i+1, j-1 ), 1 );
				}
				if( i+1 < x ) if( matrix[i+1][j] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i+1, j ), 1 );
				}
				if( i+1 < x && j+1 < y ) if( matrix[i+1][j+1] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i+1, j+1 ), 1 );
				}
				if( j+1 < y ) if( matrix[i][j+1] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i, j+1 ), 1 );
				}
				if( i-1 >= 0 && j+1 < y  ) if( matrix[i-1][j+1] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i-1, j+1 ), 1 );
				}
				if( i-1 >= 0 ) if( matrix[i-1][j] == 0 ) {
					g.SetEdge( MAKEWPARAM( i, j ), MAKEWPARAM( i-1, j ), 1 );
				}
			}
		}
	}
}
int main() {
	ofstream out( "output.txt" );
	ifstream in( "input.txt" );
	int x = 0;
	int y = 0;
	while( in ) {
		in >> x;
		in >> y;
		if( x == 0 || y == 0 ) {
			return 0;
		}
		SGraph g;
		vector< WPARAM > path;
		int ** matrix = new int* [x];
		for( int i = 0 ; i < x; ++i ) {
			matrix[i] = new int[y];
		}
		for( int j = 0 ; j < y; ++j ) {
			for( int i = 0 ; i < x; ++i ) {
				in >> matrix[i][j];
				//	cout << matrix[i][j];
				if( matrix[i][j] == 0 ) {
					// 
					g.vertex.push_back( SData( MAKEWPARAM( i, j ) ) );
				}
			}
			//	cout << "\n";
		}
		g.CreateGraph();
		init( matrix, x, y, g );
		try{
			g.Dijkstra( MAKEWPARAM( 0, 0 ), MAKEWPARAM( x-1, y-1 ), path );
			out << "good " << path.size() << "\n";
			for( int i = 0; i < (int)path.size(); ++i ) {
				out << "( " << (int) HIWORD( path[i] ) << ", ";
				out << (int)LOWORD( path[i] ) << " )\n";
			}
		}catch(...){
			out <<"error\n";
		}
		g.DeleteGraph();
		for( int i = 0 ; i < x; ++i ) {
			delete matrix[i];
		}
		delete matrix;
	}
	return 0;
}